@@ -1,10 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "consult" "3.3"
-  "Search and navigate via completing-read."
+(define-package "consult" "20251013.924"
+  "Consulting completing-read."
   '((emacs  "29.1")
     (compat "30"))
   :url "https://github.com/minad/consult"
-  :commit "312f2db1a23ef5428ab9553679147d5ff3a4e57d"
-  :revdesc "3.3-0-g312f2db1a23e"
+  :commit "da62326326b9b121edb46b0f31adb2569e4e896a"
+  :revdesc "da62326326b9"
   :keywords '("matching" "files" "completion")
   :maintainers '(("Daniel Mendler" . "mail@daniel-mendler.de")))
